==> jaguar_mongo-0.1.5.tar.gz: lib/src/interceptor.dart <==
library jaguar_mongo.interceptor;

import 'dart:async';

import 'package:jaguar/jaguar.dart';
import 'package:mongo_dart/mongo_dart.dart' as mongo;
import 'package:connection_pool/connection_pool.dart';

import 'pool.dart';

/// Wrapper for [MongoDb] interceptor
///
/// Parameters:
///   [mongoUri]: URI of mongo server
///   [poolSize]: size of the connection pool
///   [writeConcern]: write concern used when connecting to the db
class WrapMongoDb implements RouteWrapper<MongoDb> {
  /// URI of mongo server to connect to
  final String mongoUri;

  /// size of the connection pool
  final int poolSize;

  /// write concern used when connecting to the db
  final mongo.WriteConcern writeConcern;

  /// ID for the interceptor instance
  final String id;

  /// Allows making parameter from the context
  final Map<Symbol, MakeParam> makeParams;

  const WrapMongoDb(this.mongoUri,
      {this.writeConcern: mongo.WriteConcern.ACKNOWLEDGED,
      this.poolSize: 10,
      this.id,
      this.makeParams});

  /// Creates the interceptor
  MongoDb createInterceptor() =>
      new MongoDb(mongoUri, poolSize: poolSize, writeConcern: writeConcern);
}

/// Interceptor to connect to MongoDb and manage connection pool
///
/// Creates new MongoDb connection on [pre] and closes the connection on [post]
/// or [onException].
///
/// Parameters:
///   [mongoUri]: URI of mongo server
///   [poolSize]: size of the connection pool
///   [writeConcern]: write concern used when connecting to the db
class MongoDb extends Interceptor {
  /// URI of mongo server to connect to
  final String mongoUri;

  /// size of the connection pool
  final int poolSize;

  /// write concern used when connecting to the db
  final mongo.WriteConcern writeConcern;

  /// The connection pool
  MongoDbPool _pool;

  /// The connection
  ManagedConnection<mongo.Db> _managedConnection;

  /// Returns the mongodb connection
  mongo.Db get conn => _managedConnection?.conn;

  MongoDb(this.mongoUri,
      {this.writeConcern: mongo.WriteConcern.ACKNOWLEDGED, this.poolSize: 10});

  /// Establishes a connection to mongodb server on route entry
  Future<mongo.Db> pre() async {
    _pool = new MongoDbPool.Named(mongoUri,
        poolSize: poolSize, writeConcern: writeConcern);
    _managedConnection = await _pool.getConnection();
    return conn;
  }

  /// Closes the connection on route exit
  void post() {
    _releaseConn();
  }

  /// Closes the connection in case an exception occurs in route chain before
  /// [post] is called
  Future<Null> onException() async {
    _releaseConn();
  }

  /// Releases connection
  void _releaseConn() {
    if (_managedConnection != null) {
      _pool.releaseConnection(_managedConnection);
      _managedConnection = null;
    }
  }
}

==> jaguar_mongo-0.4.0.tar.gz: lib/src/interceptor.dart <==
library jaguar_mongo.interceptor;

import 'dart:async';

import 'package:jaguar/jaguar.dart';
import 'package:mongo_dart/mongo_dart.dart' as mongo;
import 'package:connection_pool/connection_pool.dart';

import 'pool.dart';

/// Wrapper for [MongoDb] interceptor
///
/// Parameters:
///   [mongoUri]: URI of mongo server
///   [poolSize]: size of the connection pool
///   [writeConcern]: write concern used when connecting to the db
class WrapMongoDb extends RouteWrapper<MongoDb> {
  /// URI of mongo server to connect to
  final String mongoUri;

  /// size of the connection pool
  final int poolSize;

  /// write concern used when connecting to the db
  final mongo.WriteConcern writeConcern;

  /// ID for the interceptor instance
  final String id;

  const WrapMongoDb(this.mongoUri,
      {this.writeConcern: mongo.WriteConcern.ACKNOWLEDGED,
      this.poolSize: 10,
      this.id});

  /// Creates the interceptor
  MongoDb createInterceptor() =>
      new MongoDb(mongoUri, poolSize: poolSize, writeConcern: writeConcern);
}

/// Interceptor to connect to MongoDb and manage connection pool
///
/// Creates new MongoDb connection on [pre] and closes the connection on [post]
/// or [onException].
///
/// Parameters:
///   [mongoUri]: URI of mongo server
///   [poolSize]: size of the connection pool
///   [writeConcern]: write concern used when connecting to the db
class MongoDb extends Interceptor {
  /// URI of mongo server to connect to
  final String mongoUri;

  /// size of the connection pool
  final int poolSize;

  /// write concern used when connecting to the db
  final mongo.WriteConcern writeConcern;

  /// The connection pool
  MongoDbPool _pool;

  /// The connection
  ManagedConnection<mongo.Db> _managedConnection;

  /// Returns the mongodb connection
  mongo.Db get conn => _managedConnection?.conn;

  MongoDb(this.mongoUri,
      {this.writeConcern: mongo.WriteConcern.ACKNOWLEDGED, this.poolSize: 10});

  /// Establishes a connection to mongodb server on route entry
  Future<mongo.Db> pre() async {
    _pool = new MongoDbPool.Named(mongoUri,
        poolSize: poolSize, writeConcern: writeConcern);
    _managedConnection = await _pool.getConnection();
    return conn;
  }

  /// Closes the connection on route exit
  void post() {
    _releaseConn();
  }

  /// Closes the connection in case an exception occurs in route chain before
  /// [post] is called
  Future<Null> onException() async {
    _releaseConn();
  }

  /// Releases connection
  void _releaseConn() {
    if (_managedConnection != null) {
      _pool.releaseConnection(_managedConnection);
      _managedConnection = null;
    }
  }
}
